Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrUnmergeableFile = errors.New("merging is not supported for file") ErrUnexpectedDelimiter = errors.New("unexpected conflict delimiter") ErrMissingEndDelimiter = errors.New("missing last delimiter") )
Errors that can occur during parsing of a merge conflict file
Functions ¶
This section is empty.
Types ¶
type File ¶
type File struct {
// contains filtered or unexported fields
}
File contains an ordered list of lines with metadata about potential conflicts.
type Resolution ¶
type Resolution struct {
OldPath string `json:"old_path"`
NewPath string `json:"new_path"`
// key is a sectionID, value is "head" or "origin"
Sections map[string]string `json:"sections"`
// Content is used when no sections are defined
Content string `json:"content"`
}
Resolution indicates how to resolve a conflict
Click to show internal directories.
Click to hide internal directories.